@@ -533,6 +533,29 @@ CREATE TABLE aliases (
 CREATE UNIQUE INDEX IF NOT EXISTS aliases_id ON aliases(old_alias, new_alias, alias_id, alias_table);
 
 -- 201810082000 down
-DROP TABLE aliases
 DROP INDEX IF EXISTS aliases_id;
+DROP TABLE IF EXISTS aliases
+
+-- 201811222222 up
+CREATE table first_login (
+  id INTEGER PRIMARY KEY AUTOINCREMENT,
+  -- sha1_sum generated by minion task mail_first_login
+  token VARCHAR(40) UNIQUE,
+  -- user who created this record
+  from_uid INTEGER REFERENCES users(id),
+  -- User for which this login token is valid
+  to_uid INTEGER REFERENCES users(id),
+  -- timestamp before which this login token is not yet valid.
+  start_date INTEGER DEFAULT 9543310605,
+  -- timestam after which this login token is no more valid.
+  stop_date INTEGER DEFAULT 1
+);
+
+CREATE INDEX first_login_stop_date ON first_login(stop_date);
+
+-- 201811222222 down
+DROP INDEX IF EXISTS first_login_stop_date;
+DROP TABLE IF EXISTS first_login;
+
+
 
